#!/bin/bash

BASE=$(cd $(dirname $0); pwd)
RESULT=0
OUTPUT=$(type systemctl > /dev/null 2>&1) || RESULT=$?
CONFIG="/etc/logger"
ETCENF="/etc/sysconfig"
INPATH="/usr/local/sbin"

# INSTALL
cp -af $BASE/logger-exec $INPATH

# CONF
[ ! -e $CONFIG ] && mkdir -p $CONFIG
if [ -f $CONFIG/logger.conf ]; then
	cp -af $BASE/logger.conf $CONFIG/logger.conf.new
	chown root.root $CONFIG/logger.conf.new
	chmod 644 $CONFIG/logger.conf.new
else
	cp -af $BASE/logger.conf $CONFIG/logger.conf
	chown root.root $CONFIG/logger.conf
	chmod 644 $CONFIG/logger.conf
fi

# ENV
[ ! -d $ETCENF ] && ETCENF="/etc/default"
if [ $RESULT -eq 0 ]; then
	cp -af $BASE/environment/logger.systemd "$ETCENF/logger"
else
	cp -af $BASE/environment/logger.init    "$ETCENF/logger"
fi

# systemd/init
if [ $RESULT -eq 0 ]; then
	cp -af $BASE/service/logger.systemd /usr/lib/systemd/system/logger.service
	systemctl enable logger.service > /dev/null 2>&1
else
	[ -f /etc/redhat-release ] && cp -af $BASE/service/logger.init.redhat   /etc/init.d/logger
	[ -f /etc/debian_version ] && cp -af $BASE/service/logger.init.debian   /etc/init.d/logger
	[ -f /etc/SUSE-brand     ] && cp -af $BASE/service/logger.init.opensuse /etc/init.d/logger
	chkconfig --add logger > /dev/null 2>&1
	chkconfig logger on    > /dev/null 2>&1
fi

# PERMISSION
[ -f /etc/init.d/logger    ] && chmod 755 /etc/init.d/logger    && chown root.root /etc/init.d/logger
[ -f /etc/sysconfig/logger ] && chmod 644 /etc/sysconfig/logger && chown root.root /etc/sysconfig/logger
[ -f /etc/default/logger   ] && chmod 644 /etc/default/logger   && chown root.root /etc/default/logger
[ -f /usr/lib/systemd/system/logger.service ] && chmod 644 /usr/lib/systemd/system/logger.service \
                                              && chown root.root /usr/lib/systemd/system/logger.service

# RELOAD
if [ $RESULT -eq 0 ]; then
	systemctl daemon-reload
fi

exit 0
